==> sepes-0.10.0.tar.gz: sepes-0.10.0/README.md <==
<!-- <h1 align="center" style="font-family:Monospace" >Py🌲Class</h1> -->
<h5 align="center">
<img width="350px" src="docs/_static/logo.svg"> <br>

<br>

Nested tree tools in python

*`sepes` is an egyptian god affiliated with trees.

![Tests](https://github.com/ASEM000/sepes/actions/workflows/test_default.yml/badge.svg)
![Tests](https://github.com/ASEM000/sepes/actions/workflows/test_jax.yml/badge.svg)
![Tests](https://github.com/ASEM000/sepes/actions/workflows/test_numpy.yml/badge.svg)
![Tests](https://github.com/ASEM000/sepes/actions/workflows/test_torch.yml/badge.svg)
![pyver](https://img.shields.io/badge/python-3.8%203.9%203.10%203.11_-blue)
![codestyle](https://img.shields.io/badge/codestyle-black-black)
[![Downloads](https://static.pepy.tech/badge/sepes)](https://pepy.tech/project/sepes)
[![codecov](https://codecov.io/gh/ASEM000/sepes/branch/main/graph/badge.svg?token=TZBRMO0UQH)](https://codecov.io/gh/ASEM000/sepes)
[![Documentation Status](https://readthedocs.org/projects/sepes/badge/?version=latest)](https://sepes.readthedocs.io/en/latest/?badge=latest)
![GitHub commit activity](https://img.shields.io/github/commit-activity/m/ASEM000/sepes)
[![DOI](https://zenodo.org/badge/512717921.svg)](https://zenodo.org/badge/latestdoi/512717921)
![PyPI](https://img.shields.io/pypi/v/sepes)
[![CodeFactor](https://www.codefactor.io/repository/github/asem000/sepes/badge)](https://www.codefactor.io/repository/github/asem000/sepes)

</h5>

## 🛠️ Installation<a id="installation"></a>

```python
pip install sepes
```

**Install development version**

```python
pip install git+https://github.com/ASEM000/sepes
```

==> sepes-0.11.2.tar.gz: sepes-0.11.2/README.md <==
<!-- <h1 align="center" style="font-family:Monospace" >Py🌲Class</h1> -->
<h5 align="center">
<img width="250px" src="https://github.com/ASEM000/sepes/assets/48389287/e3b063a4-369c-4157-92ca-017abfa7d26e"> <br>

<br>

Nested tree tools in python

\*`sepes` is an egyptian god affiliated with trees.

![Tests](https://github.com/ASEM000/sepes/actions/workflows/test_default.yml/badge.svg)
![Tests](https://github.com/ASEM000/sepes/actions/workflows/test_jax.yml/badge.svg)
![Tests](https://github.com/ASEM000/sepes/actions/workflows/test_numpy.yml/badge.svg)
![Tests](https://github.com/ASEM000/sepes/actions/workflows/test_torch.yml/badge.svg)
![pyver](https://img.shields.io/badge/python-3.8%203.9%203.10%203.11%203.12_-blue)
![codestyle](https://img.shields.io/badge/codestyle-black-black)
[![Downloads](https://static.pepy.tech/badge/sepes)](https://pepy.tech/project/sepes)
[![codecov](https://codecov.io/gh/ASEM000/sepes/branch/main/graph/badge.svg?token=TZBRMO0UQH)](https://codecov.io/gh/ASEM000/sepes)
[![Documentation Status](https://readthedocs.org/projects/sepes/badge/?version=latest)](https://sepes.readthedocs.io/en/latest/?badge=latest)
![GitHub commit activity](https://img.shields.io/github/commit-activity/m/ASEM000/sepes)
[![DOI](https://zenodo.org/badge/512717921.svg)](https://zenodo.org/badge/latestdoi/512717921)
![PyPI](https://img.shields.io/pypi/v/sepes)
[![CodeFactor](https://www.codefactor.io/repository/github/asem000/sepes/badge)](https://www.codefactor.io/repository/github/asem000/sepes)

</h5>

## 🛠️ Installation<a id="installation"></a>

```python
pip install sepes
```

**Install development version**

```python
pip install git+https://github.com/ASEM000/sepes
```
